<?php
/**
* MODULE PRESTASHOP OFFICIEL CHRONOPOST
*
* LICENSE : All rights reserved - COPY AND REDISTRIBUTION FORBIDDEN WITHOUT PRIOR CONSENT FROM OXILEO
* LICENCE : Tous droits réservés, le droit d'auteur s'applique -
* COPIE ET REDISTRIBUTION INTERDITES SANS ACCORD EXPRES D'OXILEO
*
* @author    Oxileo SAS <contact@oxileo.eu>
* @copyright 2001-2018 Oxileo SAS
* @license   Proprietary - no redistribution without authorization
*/
if (defined('__PS_VERSION_')) {
    exit('Restricted Access');
}

require_once(dirname(__FILE__).'/AdminExportChronopost.php');

class AdminExportChronofreshController extends AdminExportChronopostController
{
    public function __construct()
    {
        parent::__construct();
        
        // Translations that will need to be picked up
        $this->l('Customer');
        $this->l('Payment');
        $this->l('Status');
        $this->l('Date');
        $this->l('Waybills');
        $this->l('Account to use');
        $this->l('Saturday delivery');
        $this->l('Weight');
        $this->l('Length');
        $this->l('Height');
        $this->l('Width');
        $this->l('CSS export');
        $this->l('Print all waybills');
        $this->l(
            'For an export, select orders, then in the "Bulk Actions" menu, '
            .'select the type of export wanted.'
        );
        $this->l("If the download doesn't start automatically, click here to download your file");

        // fields_lists *HAS* to be initiated in constructor, not later
        $this->fields_list = array_merge($this->fields_list, array(
            'dlc' => array(
                'title' => $this->l('BBD'),
                'align' => 'text-center',
                'callback' =>'dlcInput',
                'orderby' => false,
                'search' => false
            ),
            'chrono_product' => array(
                'title' => $this->l('Product to use'),
                'align' => 'text-center',
                'callback' => 'productInput',
                'orderby' => false,
                'search' => false,
                'class' => 'fixed-width-lg'
            ),
        ));
        $this->fields_list['account']['callback'] = 'accountInputFresh';
        unset($this->fields_list['saturday']);
    }

    public function setMedia($isNewTheme = false)
    {
        parent::setMedia($isNewTheme);
        $this->removeJS(_MODULE_DIR_."chronopost/views/js/exportMenu.js");
        $this->addJS(_MODULE_DIR_."chronopost/views/js/exportMenuChronofresh.js");
    }

    public function accountInputFresh($id_order){

        $this->accountInputAssign($id_order);

        return $this->context->smarty->fetch(dirname(__FILE__).'/../../views/templates/admin/account_input_fresh.tpl');
    }
    
    public function dlcInput($id_order)
    {
        $daysAfter = Configuration::get('CHRONOPOST_CHRONOFRESH_DLC');
        $now = new DateTime();
        $dlc_default = $now->add(new DateInterval("P{$daysAfter}D"))->format("Y-m-d");

        $this->context->smarty->assign(array(
            'id_order'    => $id_order,
            'dlc_default' => $dlc_default
        ));
        return $this->context->smarty->fetch(dirname(__FILE__).'/../../views/templates/admin/dlc_input.tpl');
    }

    public function productInput($id_order){

        $wsHelper = Chronopost::getWsHelper();
        $availChronoFreshCodes = $wsHelper->getChronofreshCodes();
        $availChronoFreshProducts = [];
        foreach ($availChronoFreshCodes as $code) {
            $key = array_search(
                $code,
                array_column(Chronopost::$carriersDefinitions['CHRONOFRESH']['products'], 'code')
            );
            if (is_int($key)) {
                $availChronoFreshProducts[] = Chronopost::$carriersDefinitions['CHRONOFRESH']['products'][$key];
            }
        }

        $this->context->smarty->assign(array(
            'id_order' => $id_order,
            'available_products' => $availChronoFreshProducts,
        ));

        return $this->context->smarty->fetch(dirname(__FILE__).'/../../views/templates/admin/product_input.tpl');
    }
}
